@@ -338,6 +338,50 @@ used within subsequent DSL statements. See also "Regular expressions" at ` + lib
 			regexCaptureBinaryFunc: bifs.BIF_string_does_not_match_regexp,
 		},
 
+		{
+			name:  "strmatch",
+			class: FUNC_CLASS_STRING,
+			help:  `Boolean yes/no for whether the stringable first argument matches the regular-expression second argument. No regex captures are provided; please see ` + "`strmatch`.",
+			examples: []string{
+				`strmatch("a", "abc") is false`,
+				`strmatch("abc", "a") is true`,
+				`strmatch("abc", "a[a-z]c") is true`,
+				`strmatch("abc", "(a).(c)") is true`,
+				`strmatch(12345, "34") is true`,
+			},
+			binaryFunc: bifs.BIF_strmatch,
+		},
+
+		{
+			name:  "strmatchx",
+			class: FUNC_CLASS_STRING,
+			help:  `Extended information for whether the stringable first argument matches the regular-expression second argument. Regex captures are provided in the return-value map; \1, \2, etc. are not set, in contrast to the ` + "`=~` operator. As well, while the `=~` operator limits matches to \\1 through \\9, an arbitrary number are supported here.",
+			examples: []string{
+				`strmatchx("a", "abc") returns:`,
+				`  {`,
+				`    "matched": false`,
+				`  }`,
+				`strmatchx("abc", "a") returns:`,
+				`  {`,
+				`    "matched": true,`,
+				`    "full_capture": "a",`,
+				`    "full_start": 1,`,
+				`    "full_end": 1`,
+				`  }`,
+				`strmatchx("[zy:3458]", "([a-z]+):([0-9]+)") returns:`,
+				`  {`,
+				`    "matched": true,`,
+				`    "full_capture": "zy:3458",`,
+				`    "full_start": 2,`,
+				`    "full_end": 8,`,
+				`    "captures": ["zy", "3458"],`,
+				`    "starts": [2, 5],`,
+				`    "ends": [3, 8]`,
+				`  }`,
+			},
+			binaryFunc: bifs.BIF_strmatchx,
+		},
+
 		{
 			name:       "&&",
 			class:      FUNC_CLASS_BOOLEAN,
@@ -400,7 +444,7 @@ used within subsequent DSL statements. See also "Regular expressions" at ` + lib
 		{
 			name:      "clean_whitespace",
 			class:     FUNC_CLASS_STRING,
-			help:      "Same as collapse_whitespace and strip.",
+			help:      "Same as collapse_whitespace and strip, followed by type inference.",
 			unaryFunc: bifs.BIF_clean_whitespace,
 		},
 
