@@ -22,15 +22,15 @@ func (writer *RecordWriterDKVP) Write(
 	outrec *mlrval.Mlrmap,
 	bufferedOutputStream *bufio.Writer,
 	outputIsStdout bool,
-) {
+) error {
 	// End of record stream: nothing special for this output format
 	if outrec == nil {
-		return
+		return nil
 	}
 
 	if outrec.IsEmpty() {
 		bufferedOutputStream.WriteString(writer.writerOptions.ORS)
-		return
+		return nil
 	}
 
 	for pe := outrec.Head; pe != nil; pe = pe.Next {
@@ -42,4 +42,6 @@ func (writer *RecordWriterDKVP) Write(
 		}
 	}
 	bufferedOutputStream.WriteString(writer.writerOptions.ORS)
+
+	return nil
 }
